/*
** Static Import Example of ES Modules
*/

// Import the module from the asset folder. This can also be a CDN or any accessible URL where the module is accessible
  import { ModuleTest } from '/wp-content/uploads/ac_assets/load_module_sample/MyModule.js'

    
// Since static imports have to be at the top of the declaration, we use the twig variable {{uc_serial}} as a prefix for our variables so that we can
// have unique variable names for each widget instance on the same page
    
    
  // Define some options that we will send to the class in our module.
  const options_{{uc_serial}} = {
      div: document.querySelector('#{{uc_id}}'),
      deleteOnClick: {{delete_on_click}}
  }

  // The above module we imported, exports a class called ModuleTest, in the next line we instantiate that class with the options we defined above
  const myInstance_{{uc_serial}} = new ModuleTest(options_{{uc_serial}})

  // We call a method of that class based on a widget setting
  {% if log_options == 'true' %}
      myInstance_{{uc_serial}}.logOptions()
  {% endif %}


/*
** Dynamic Import Example of ES Modules
*/

//  Unlike Static Imports, Dynamic imports can be done anywhere in the editor. Instead of using the Twig variable {{uc_serial}} as a prefix, we can wrap the whole code in {} 
// to create separate scopes
{

  // Define some options that we will send to the class in our module.
  const options = {
      div: document.querySelector('#{{uc_id}}'),
      deleteOnClick: {{delete_on_click}}
  }
 
  // define a variable to hold the instance of our class
  let myInstance = null
 
  // Import the module using the Import function
  import('/wp-content/uploads/ac_assets/load_module_sample/MyModule.js')
    .then(module => {
          
    	// The import method return a promise so we initiate the class inside the then clause 
        myInstance = new module.ModuleTest(options)
		
    	// Run the custom code that relies on the module
    	init()
    })
	
  // We wrap other code that depends on the module in a seperate function for readability sake. if the code is short, like here, we can just add it in the promise's then clause
  const init = () => {
    
    // We call a method of that class based on a widget setting
    {% if log_options == 'true' %}
        myInstance.logOptions()
    {% endif %}
    
  }
}